<?php
/*
 Plugin Name: CaptchaAd
 Plugin URI: http://www.captchaad.com/
 Description: Integrates CaptchaAd to protect comment posts and registrations
 Version: 1.0
 Author: CaptchaAd GmbH
 Author URI: http://www.captchaad.com/
 */

// http://codex.wordpress.org/Writing_a_Plugin
// http://codex.wordpress.org/I18n_for_WordPress_Developers

require_once dirname(__FILE__) . '/config.inc.php';

cadInit();
register_activation_hook( __FILE__, 'cadSetDefaultOptions');
register_deactivation_hook( __FILE__, 'cadRemoveOptions');

/**
 * Init plugin options and hooks
 * @global array $captchaAd_options
 */
function cadInit()
{
	global $captchaAd_options;
	// Load Language Files
	load_plugin_textdomain('captchaAdLang', false, basename( dirname( __FILE__ ) ) . '/languages');

	add_action('admin_menu', 'cadAddOptionsPage');

	$captchaAd_options = get_option('CaptchaAd');

	$captchaAd_problems = cadCheckOptions($captchaAd_options);

	//if (empty($captchaAd_problems) && $captchaAd_options['DISPLAY_IN_COMMENT'] == 1 || $captchaAd_options['DISPLAY_IN_REGISTRATION'] == 1) {
	if ($captchaAd_options['DISPLAY_IN_COMMENT'] == 1 || $captchaAd_options['DISPLAY_IN_REGISTRATION'] == 1) {

		require_once $captchaAd_options['BASE_PATH'] . 'captchaad.lib.php';

		if ($captchaAd_options['DISPLAY_IN_COMMENT'] == 1) {
			add_action('wp_head', 'cadHtmlHeader');
			add_filter('comment_form_defaults', 'cadField');
			add_filter('preprocess_comment', 'cadCheckComment', 1);
		}

		if ($captchaAd_options['DISPLAY_IN_REGISTRATION'] == 1) {
			add_action('login_head', 'cadHtmlHeader');
			add_action('register_form', 'cadHtmlBody');
			add_filter('registration_errors', 'cadCheckRegistration', 1);
		}

	}
}
/**
 * Inject CaptchaAd after comment_note_after
 */
function cadField( $comment_form_defaults ) {
	ob_start();
	cadHtmlBody();
	$comment_form_defaults['comment_notes_after'] .= ob_get_contents();
	ob_end_clean();

	return $comment_form_defaults;
}

/**
 * Set the plugin default options (once)
 * @global array $captchaAd_lang
 */
function cadSetDefaultOptions()
{
	global $captchaAd_lang;

	$defaultOptions = array(
		'BASE_PATH'					=> dirname(__FILE__) . '/',
		'BASE_URL'					=> WP_PLUGIN_URL . '/' . str_replace(basename( __FILE__), '', plugin_basename(__FILE__)),
		'API_KEY'					=> '',
		'PUBLISHER_ID'				=> '',
		'ZONE_ID'					=> '',
		'RECAPTCHA_PUBLIC_KEY'		=> '',
		'RECAPTCHA_PRIVATE_KEY'		=> '',
		'DISPLAY_IN_COMMENT'		=> '0',
		'DISPLAY_IN_REGISTRATION'	=> '0',
		'LANG'						=> 'DE',
		'ALTTEXT'					=> $captchaAd_lang['DE']['ALTTEXT'],
		'WIDTH'						=> '',
		'HEIGHT'					=> '',
	);

	add_option('CaptchaAd', $defaultOptions, 'CaptchaAd Default Options', 'yes');
}

/**
 * Remove the CaptchaAd Options
 */
function cadRemoveOptions()
{
	delete_option('CaptchaAd');
}

/**
 * Add the plugin configuration page
 */
function cadAddOptionsPage()
{
	add_options_page('CaptchaAd', 'CaptchaAd', 'manage_options', __FILE__, 'cadOptionsPage');
}

/**
 * Display the options page in the backend to do some settings
 * @global array $captchaAd_options
 * @global array $captchaAd_problems
 * @global array $captchaAd_lang
 */
function cadOptionsPage()
{
	global $captchaAd_options, $captchaAd_problems, $captchaAd_lang;

	$isPost = false;
	$updatedOptions = false;

	if (isset($_POST['action']) && $_POST['action'] == 'update') {

		$isPost = true;

		$newOptions = array(
			'API_KEY'					=> $_POST['API_KEY'],
			'PUBLISHER_ID'				=> $_POST['PUBLISHER_ID'],
			'ZONE_ID'					=> $_POST['ZONE_ID'],
			'RECAPTCHA_PUBLIC_KEY'		=> $_POST['RECAPTCHA_PUBLIC_KEY'],
			'RECAPTCHA_PRIVATE_KEY'		=> $_POST['RECAPTCHA_PRIVATE_KEY'],
			'DISPLAY_IN_COMMENT'		=> $_POST['DISPLAY_IN_COMMENT'],
			'DISPLAY_IN_REGISTRATION'	=> $_POST['DISPLAY_IN_REGISTRATION'],
			'LANG'						=> $_POST['LANG'],
			'ALTTEXT'					=> str_replace("\r\n", "", $_POST['ALTTEXT']), // Zeilenumbrueche fuehren zu Problemen, daher werden sie hier entfernt.
			'WIDTH'						=> $_POST['WIDTH'],
			'HEIGHT'					=> $_POST['HEIGHT'],
		);

		if (cadOverwriteOptions($newOptions)) {
			$updatedOptions = true;
		}
	}
?>

<style type="text/css">
	.req{color:#CC0000;}
	input.error{border-color:#CC0000;}
</style>
<script type="text/javascript">
	var alttext = [];
	<?php foreach ($captchaAd_lang as $key => $data) : ?>
	alttext["<?php echo $key; ?>"] = "<?php echo $data['ALTTEXT']; ?>";
	<?php endforeach; ?>

	// on language change: set the default ALTTEXT
	function setAlttext(langKey)
	{
		jQuery('#ALTTEXT').val(alttext[langKey]);
	}
	
</script>
<div class="wrap">

	<?php if ($isPost) : ?>
		<?php if ($updatedOptions) : ?>
			<div class="updated"><?php _e('Update successfull.','captchaAdLang');?></div>
		<?php else : ?>
			<div class="error"><?php _e('Sorry, something went wrong.','captchaAdLang');?></div>
		<?php endif; ?>
	<?php endif; ?>

	<div class="icon32" id="icon-options-general" style="float:left"><br></div>

	<h2 style="position:relative"><?php _e('Options &rsaquo;&nbsp;&nbsp;','captchaAdLang');?><img style="position:absolute;top:0;" src="<?php echo $captchaAd_options['BASE_URL']; ?>/img/logo.png" alt="CaptchaAd" width="165" height="45"></h2>

	<div style="clear:both"></div>

	<p><?php _e('Please contact CaptchaAd for the required informations.','captchaAdLang');?></p>

	<form method="post" action="">

		<table class="form-table">

			<tr valign="top">
				<th scope="row">
					<label for="API_KEY"><?php _e('API Key','captchaAdLang');?> <span class="req">*</span></label>
				</th>
				<td>
					<input id="API_KEY" name="API_KEY" type="text" class="regular-text <?php if (in_array('API_KEY', $captchaAd_problems)) : ?>error<?php endif; ?>" value="<?php echo attribute_escape($captchaAd_options['API_KEY']); ?>" />
					<br />
					<span class="description">
          <?php _e('The 32-digit API key is used for identification.<br />
					To use the CaptchaAd plugin, you need this key.<br />
					You get this key from CaptchaAd.<br />
          Fon: +49 (0) 89.237 129 21<br />
					Mail: <a href="mailto:wordpress@captchaad.com">wordpress@captchaad.com</a>','captchaAdLang');?>
					</span>
				</td>
			</tr>

			<tr valign="top">
				<th scope="row">
					<label><?php _e('Show at','captchaAdLang');?></label>
				</th>
				<td>
					<label><input id="DISPLAY_IN_COMMENT" name="DISPLAY_IN_COMMENT" type="checkbox" value="1" <?php checked('1', $captchaAd_options['DISPLAY_IN_COMMENT']); ?> /> <?php _e('Comments','captchaAdLang');?></label>
				</td>
			</tr>

			<tr valign="top">
				<th scope="row"></th>
				<td>
					<label><input id="DISPLAY_IN_REGISTRATION" name="DISPLAY_IN_REGISTRATION" type="checkbox" value="1" <?php checked('1', $captchaAd_options['DISPLAY_IN_REGISTRATION']); ?> /> <?php _e('Registration','captchaAdLang');?></label>
				</td>
			</tr>

		</table>

		<h3><?php _e('Options','captchaAdLang');?></h3>

		<table class="form-table">

			<tr valign="top">
				<th scope="row">
					<label for="LANG"><?php _e('Language','captchaAdLang');?></label>
				</th>
				<td>
					<select name="LANG" class="<?php if (in_array('LANG', $captchaAd_problems)) : ?>error<?php endif; ?>" onchange="setAlttext(this.value);">
						<?php
						foreach ($captchaAd_lang as $k => $data) {
						  $selLang = '';
						  if ($captchaAd_options['LANG'] == $k) {
								$selLang = 'selected="selected"';
								if($captchaAd_options['ALTTEXT'] == '') $captchaAd_options['ALTTEXT'] = $data['ALTTEXT']; // Setzt den Altext so er leer ist!
						  }
							echo '<option value="'.$k.'" '.$selLang.'>'.$data['LABEL'].'</option>';
						}
						?>
					</select>
				</td>
			</tr>

			<tr valign="top">
				<th scope="row">
					<label for="ALTTEXT"><?php _e('Welcome text','captchaAdLang');?></label>
				</th>
				<td>
					<textarea id="ALTTEXT" name="ALTTEXT" class="<?php if (in_array('ALTTEXT', $captchaAd_problems)) : ?>error<?php endif; ?>" style="width:25em"><?php echo attribute_escape($captchaAd_options['ALTTEXT']); ?></textarea>
				</td>
			</tr>

			<!--
			<tr valign="top">
				<th scope="row"><?php _e('Representation','captchaAdLang');?></th>
				<td>
					<label for="WIDTH"><?php _e('Width','captchaAdLang');?></label>
					<input id="WIDTH" name="WIDTH" type="text" class="small-text <?php if (in_array('WIDTH', $captchaAd_problems)) : ?>error<?php endif; ?>" value="<?php echo attribute_escape($captchaAd_options['WIDTH']); ?>" />
					x

					<label for="HEIGHT"><?php _e('Height','captchaAdLang');?></label>
					<input id="HEIGHT" name="HEIGHT" type="text" class="small-text <?php if (in_array('HEIGHT', $captchaAd_problems)) : ?>error<?php endif; ?>" value="<?php echo attribute_escape($captchaAd_options['HEIGHT']); ?>" />
				</td>
			</tr>
			-->

		</table>

		<h3><?php _e('Advertisement <small>(optional)</small>','captchaAdLang');?></h3>

		<p><?php _e('CaptchaAd offers the possibility of video advertising.<br />
		To enable this feature, you need a Publisher ID and a Zone ID. Both are available on request at CaptchaAd:<br />
		Fon: +49 (0) 89.237 129 21<br />
		Mail: <a href="mailto:wordpress@captchaad.com">wordpress@captchaad.com</a><br />
		<br />
		Leave this boxes empty if you want to show any advertising videos inside of CaptchaAds.','captchaAdLang');?></p>

		<table class="form-table">

			<tr valign="top">
				<th scope="row">
					<label for="PUBLISHER_ID"><?php _e('Publisher Id','captchaAdLang');?></label>
				</th>
				<td>
					<input id="PUBLISHER_ID" name="PUBLISHER_ID" type="text" class="regular-text <?php if (in_array('PUBLISHER_ID', $captchaAd_problems)) : ?>error<?php endif; ?>" value="<?php echo attribute_escape($captchaAd_options['PUBLISHER_ID']); ?>" />
				</td>
			</tr>

			<tr valign="top">
				<th scope="row">
					<label for="ZONE_ID"><?php _e('Zone Id','captchaAdLang');?></label>
				</th>
				<td>
					<input id="ZONE_ID" name="ZONE_ID" type="text" class="regular-text <?php if (in_array('ZONE_ID', $captchaAd_problems)) : ?>error<?php endif; ?>" value="<?php echo attribute_escape($captchaAd_options['ZONE_ID']); ?>" />
				</td>
			</tr>

		</table>


		<h3><?php _e('reCAPTCHA <small>(&copy; Google)</small>','captchaAdLang');?></h3>

		<p><?php _e('To ensure spam protection, CaptchaAd requires an alternative in case of disabled Flash or JavaScript. <a href="http://www.google.com/recaptcha" target="_blank">reCAPTCHA</a> will be displayed instead.','captchaAdLang');?></p>

		<table class="form-table">

			<tr valign="top">
				<th scope="row">
					<label for="RECAPTCHA_PUBLIC_KEY"><?php _e('Public Key','captchaAdLang');?> <span class="req">*</span></label>
				</th>
				<td>
					<input id="RECAPTCHA_PUBLIC_KEY" name="RECAPTCHA_PUBLIC_KEY" type="text" class="regular-text <?php if (in_array('RECAPTCHA_PUBLIC_KEY', $captchaAd_problems)) : ?>error<?php endif; ?>" value="<?php echo attribute_escape($captchaAd_options['RECAPTCHA_PUBLIC_KEY']); ?>" />
					<br />
					<span class="description"><?php _e('Public Key from reCAPTCHA','captchaAdLang');?></span>
				</td>
			</tr>

			<tr valign="top">
				<th scope="row">
					<label for="RECAPTCHA_PRIVATE_KEY"><?php _e('Private Key','captchaAdLang');?> <span class="req">*</span></label>
				</th>
				<td>
					<input id="RECAPTCHA_PRIVATE_KEY" name="RECAPTCHA_PRIVATE_KEY" type="text" class="regular-text <?php if (in_array('RECAPTCHA_PRIVATE_KEY', $captchaAd_problems)) : ?>error<?php endif; ?>" value="<?php echo attribute_escape($captchaAd_options['RECAPTCHA_PRIVATE_KEY']); ?>" />
					<br />
					<span class="description"><?php _e('Private Key from reCAPTCHA','captchaAdLang');?></span>
				</td>
			</tr>

		</table>

		<p class="submit"><input type="hidden" name="action" value="update" /> <input type="submit" name="Submit" value="<?php _e('Save Changes','captchaAdLang') ?>" class="button-primary" /></p>
	</form>
</div>
<?php
}

/**
 * Update and overwrite the global options
 * @global array $captchaAd_options
 * @global array $captchaAd_problems
 * @param array $newOptions
 * @return bool successful?
 */
function cadOverwriteOptions($newOptions)
{
	global $captchaAd_options, $captchaAd_problems;

	$captchaAd_problems = cadCheckOptions($newOptions);

	if (empty($captchaAd_problems)) {

		$newOptions = array_merge($captchaAd_options, $newOptions);

		// to avoid problems through the input filtering functions only overwrite
		// the global options when the update was successfully
		if (update_option('CaptchaAd', $newOptions)) {
			$captchaAd_options = $newOptions;
			return true;
		}
	}

	return false;
}

/**
 * Check the (required) options
 * @param array $captchaAd_options
 * @return array a list of incorrect options
 */
function cadCheckOptions($captchaAd_options)
{
	$captchaAd_problems = array();

	if (empty($captchaAd_options['API_KEY']) || mb_strlen($captchaAd_options['API_KEY']) != 32) {
		$captchaAd_problems[] = 'API_KEY';
	}

	if (!empty($captchaAd_options['WIDTH']) || (int) $captchaAd_options['WIDTH'] != 0) {
		$captchaAd_problems[] = 'WIDTH';
	}

	if (!empty($captchaAd_options['HEIGHT']) || (int) $captchaAd_options['HEIGHT'] != 0) {
		$captchaAd_problems[] = 'HEIGHT';
	}

	if (!empty($captchaAd_options['PUBLISHER_ID']) && (int) $captchaAd_options['PUBLISHER_ID'] < 1) {
		$captchaAd_problems[] = 'PUBLISHER_ID';
	}

	if (!empty($captchaAd_options['ZONE_ID']) && (int) $captchaAd_options['ZONE_ID'] < 1) {
		$captchaAd_problems[] = 'ZONE_ID';
	}

	if (empty($captchaAd_options['RECAPTCHA_PUBLIC_KEY'])) {
		$captchaAd_problems[] = 'RECAPTCHA_PUBLIC_KEY';
	}

	if (empty($captchaAd_options['RECAPTCHA_PRIVATE_KEY'])) {
		$captchaAd_problems[] = 'RECAPTCHA_PRIVATE_KEY';
	}

	return $captchaAd_problems;
}

?>
